# Supplychain Python Library


![Linter](https://github.com/Cosmo-Tech/supplychain-python-library/actions/workflows/linter.yml/badge.svg)
![Tests](https://github.com/Cosmo-Tech/supplychain-python-library/actions/workflows/tests.yml/badge.svg)

This library was made to have an accessible way to use the supplychain python code

## Documentation

- [Protocol](Supplychain/Protocol/README.md)